/*==============================================================================
FICHA: Indicador N03 - Porcentaje de recin nacidos con dos controles CRED
ELABORACION: DIRESA SAN MARTN - JCAR
==============================================================================*/
use DataHIS
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, convert(date,FECHA_ATENCION) fecha_atencion
	, convert(int,ANIO+MES) aniomes
	, p.NUMERO_DOCUMENTO num_doc
	, TIPO_DIAGNOSTICO tipo_dx
	, CODIGO_ITEM cod_item  
	, valor_lab
into #his_minsa
from HIS_Nominal h inner join PACIENTE p on h.ID_PACIENTE=p.ID_PACIENTE -- with (nolock)
where CODIGO_ITEM in (
					'99381.01'								--CRED RN
					,'P070','P0711','P0712'					--Dx BPN o Prematuro
				)
and ID_TIPO_DOCUMENTO in (1,6) -- and sw=1

--insert into #his_minsa
--select id_cita
--	, convert(date,periodo) fecha_atencion
--	, convert(int,aniomes) aniomes
--	, num_doc
--	, id_tipitem tipo_dx
--	, cod_item  
--	, valor_lab
--from [lnksumatika].fed_midis.dbo.TramaHisMinsa_202212_20230124 with (nolock)
--where cod_item in (
--					'99381.01'								--CRED RN
--					,'P070','P0711','P0712'					--Dx BPN o Prematuro
--				)
--and id_tipo_doc in (1,6) and sw=1

--PADRON NOMINAL
select distinct case when nu_dni_menor is null or nu_dni_menor in ('','null') then nu_cnv	
				else nu_dni_menor end num_doc,
				Cod_ubigeo ubigeo,
				t_seguro seguro,
				convert(date,Fecha_nac) fecha_nac
into #padron_nominal
from PN_FED with (nolock)
where convert(int,t_Tipo_Doc) in (1,3)
--and (sw_pn=1 or sw_cnv=1) -- Validacion Dni o CNV


--***************************************************
--					SINTAXIS
--***************************************************
create table #tabla_reporte
(
num_doc nvarchar(8)
, fecha_nac date
, ubigeo int 
, seguro varchar(50)
, ao int  
, mes int
, den int
, num int
, fecha_cred1 date 
, cred1 int 
, fecha_cred2 date 
, cred2 int
) 

declare @mes_inicio int,
		@mes_eval int,
		@ao int ,
		@fec_eval date

set @mes_inicio=1 --<========= Mes inicio
set @mes_eval=2  --<=========== Mes de evaluacin
set @ao=2023 --<============= Ao de evaluacin 

while @mes_inicio<=@mes_eval
begin

--%%%%%%%%%%%%%%%%
--  DENOMINADOR
--%%%%%%%%%%%%%%%%

--1.Total de nias/nios recin nacidos de 14 das de edad en el periodo de evaluacin
select distinct	num_doc
			 , fecha_nac
			 , dateadd(dd,14,fecha_nac) fecha_corte
			 , ubigeo
			 , seguro
into #padron_den
from #padron_nominal
where month(dateadd(dd,14,fecha_nac))=@mes_inicio
  and year(dateadd(dd,14,fecha_nac))=@ao

--2.Excluyendo los recin nacidos que registran en HIS bajo peso al nacer
select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, bpn=1
into #padron_bpn
from #padron_den a
inner join #his_minsa b on a.num_doc=b.num_doc
where b.cod_item in ('P070','P0711','P0712') and (b.fecha_atencion between a.fecha_nac and a.fecha_corte)

select distinct a.num_doc, a.fecha_nac, a.fecha_corte, a.ubigeo, a.seguro, den=1
into #padron_den_final
from #padron_den a
left join #padron_bpn b on a.num_doc=b.num_doc and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro and a.ubigeo=b.ubigeo
where b.bpn is null


--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%
--1.Registraron en HIS al menos 2 controles CRED (CPMS: 99381.01) hasta los 14 das
	
	--1.1 El primer control del CRED a partir del tercer da de vida en adelante.
	select a.*, b.fecha_atencion fecha_cred1
	into #padron_num_cred1
	from #padron_den_final a
	inner join #his_minsa b on a.num_doc=b.num_doc
	where b.cod_item='99381.01' and (b.fecha_atencion between dateadd(dd,3,a.fecha_nac) and a.fecha_corte) 

	--1.2 El segundo control del CRED (intervalo mnimo entre controles del recin nacido es de 03 das)
	select a.*, b.fecha_atencion fecha_cred2
	into #padron_num_cred2
	from #padron_num_cred1 a
	inner join #his_minsa b on a.num_doc=b.num_doc
	where b.cod_item='99381.01' and (b.fecha_atencion between dateadd(dd,3,a.fecha_nac) and a.fecha_corte) 
	and b.fecha_atencion>=dateadd(dd,3,a.fecha_cred1)

--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
insert into #tabla_reporte
select a.num_doc, a.fecha_nac, a.ubigeo, a.seguro
, year(a.fecha_corte) ao, month(a.fecha_corte) mes
, den=1, iif(b.cred1=1 and c.cred2=1,1,0) num			-- Numerador (CRED RN1 + CRED RN2)
, b.fecha_cred1, isnull(b.cred1,0) cred1				-- CRED RN 1
, c.fecha_cred2, isnull(c.cred2,0) cred2				-- CRED RN 2
from #padron_den_final a
left join 
		(select num_doc,fecha_nac, ubigeo, seguro, min(fecha_cred1) fecha_cred1, cred1=1 from #padron_num_cred1
		group by num_doc,fecha_nac, ubigeo, seguro) b on a.fecha_nac=b.fecha_nac and a.num_doc=b.num_doc and a.ubigeo=b.ubigeo and a.seguro=b.seguro
left join 
		(select num_doc,fecha_nac, ubigeo, seguro, min(fecha_cred2) fecha_cred2, cred2=1 from #padron_num_cred2
		group by num_doc,fecha_nac, ubigeo, seguro) c on a.fecha_nac=c.fecha_nac and a.num_doc=c.num_doc and a.ubigeo=c.ubigeo and a.seguro=c.seguro
	
drop table #padron_bpn
drop table #padron_den
drop table #padron_den_final
drop table #padron_num_cred1
drop table #padron_num_cred2

set @mes_inicio = @mes_inicio + 1
end

--===================
-- REPORTE
--===================
--drop table BD_HISINDICADORES.dbo.DL1153_2023_CG03_RnCRED
drop table TRAMAHIS_DL_CG03_2023

select 
B.diris Diris, CASE 
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.DESC_DPTO END Departamento
, B.desc_prov Provincia
, B.desc_dist Distrito
, B.Red
, a.*
into TRAMAHIS_DL_CG03_2023
from #tabla_reporte a
inner join MAESTRO_UBIGEO b on CONVERT(int,a.ubigeo)=CONVERT(int,b.ubigeo) 

select Diris, Departamento, Provincia, Distrito, Red, ubigeo, seguro, mes, ao 
, sum(den) den, sum(num) num, sum(cred1) cred1, sum(cred2) cred2
from TRAMAHIS_DL_CG03_2023
group by Diris, Departamento, Provincia, Distrito, Red, ubigeo, seguro, mes, ao 


drop table #his_minsa
drop table #padron_nominal
drop table #tabla_reporte
-- =D

--select Ao, Mes, Ubigeo, Provincia, Distrito, Red, num_doc, fecha_nac, seguro, den, num, fecha_cred1,fecha_cred2 from TRAMAHIS_DL_CG03_2023
