/*==============================================================================
FICHA: Indicador N04 -  Porcentaje de nias y nios menores de 2 aos en condicin de 
riesgo nutricional que luego de un periodo de seguimiento mejora sus condiciones nutricionales. 
ELABORACION: DIRESA SAN MARTN - JCAR
==============================================================================*/
use DataHIS
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, e.Codigo_Unico renaes
	, convert(date,FECHA_ATENCION) fecha_atencion
	, convert(int,ANIO+MES) aniomes
	, p.NUMERO_DOCUMENTO num_doc
	, TIPO_DIAGNOSTICO tipo_dx
	, CODIGO_ITEM cod_item  
	, valor_lab
	, TIPO_EDAD id_tipedad_reg
	, edad_reg
into #his_minsa
from HIS_Nominal h 
left join PACIENTE p on h.ID_PACIENTE=p.ID_PACIENTE --with (nolock)
left join ESTABLECIMIENTOS e on h.ID_ESTABLECIMIENTO=e.Id_Establecimiento
where CODIGO_ITEM in (
					'R628'						--Faltas del desarrollo fisiolgico normal esperado
					,'Z006'						--Estado nutricional en condicin de normalidad
				)
and ID_TIPO_DOCUMENTO=1 -- and sw=1

--insert into #his_minsa
--select id_cita
--	, renaes
--	, convert(date,periodo) fecha_atencion
--	, convert(int,aniomes) aniomes
--	, num_doc
--	, id_tipitem tipo_dx
--	, cod_item  
--	, valor_lab
--	, id_tipedad_reg
--	, edad_reg
--from [lnksumatika].fed_midis.dbo.TramaHisMinsa_202212_20230124 with (nolock)
--where cod_item in (
--					'R628'						--Faltas del desarrollo fisiolgico normal esperado
--					,'Z006'						--Estado nutricional en condicin de normalidad
--				)
--and id_tipo_doc=1 and sw=1

--***************************************************
--					SINTAXIS
--***************************************************
create table #tabla_reporte
(
renaes int
, num_doc nvarchar(8)
, fecha_dx date
, ao int
, mes int
, den int
, num int
, num_1 int
, fecha_num1 date
, num_2 int
, fecha_num2 date
) 

declare @mes_inicio int,
		@mes_eval int,
		@ao int ,
		@fec_eval date

set @mes_inicio=1   --<=========== Mes de inicio
set @mes_eval=2 --<=========== Mes de evaluacin
set @ao=2023 --<============= Ao de evaluacin 

while @mes_inicio<=@mes_eval
begin

set @fec_eval=eomonth( convert(date, convert(char(4),@ao)+right('00'+convert(nvarchar(2),@mes_inicio),2)+'01') )

--%%%%%%%%%%%%%%%%
--  DENOMINADOR
--%%%%%%%%%%%%%%%%

--1.Nias y nios menores de 730 das que en el perodo de evaluacin, acuden al establecimiento de salud por cualquier motivo de consulta 
select distinct	num_doc
				, renaes
				, @ao ao
				, @mes_inicio mes
				, max(fecha_atencion) fecha_dx
into #his_minsa_den
from #his_minsa
where cod_item='R628' and valor_lab in ('TP','PT','PE')
	 and tipo_dx='D'
	 and ( (id_tipedad_reg in ('D','M')) or (id_tipedad_reg='A' and edad_reg=1) )
     and ( fecha_atencion between dateadd(dd,-100, @fec_eval) and dateadd(dd,-60, @fec_eval) ) 
group by num_doc, renaes

--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%
--1.partir del ltimo diagnstico definitivo de condicin de riesgo nutricional recobran 
--  la condicin de normalidad en rango de 60 a 100 das a partir del diagnstico y cumple el siguiente criterio
	
	--1.1 1.Registran en HIS su recuperacin con diagnstico repetitivo
	select *
	into #his_minsa_num1
	from (
			select a.num_Doc, a.renaes, max(b.fecha_atencion) fecha_num1, num1=1
			from #his_minsa_den a
			inner join #his_minsa b on a.num_doc=b.num_doc and a.renaes=b.renaes
			where (b.fecha_atencion between dateadd(dd,60,a.fecha_dx) and dateadd(dd,100,a.fecha_dx))
			and b.cod_item='R628' and valor_lab in ('TP','PT','PE')
			and b.tipo_dx='R'
			and b.id_cita in (select distinct id_cita from #his_minsa where cod_item  in ('R628') and tipo_dx='R' and valor_lab='PR') 
			and b.fecha_atencion<=@fec_eval
			group by a.num_Doc, a.renaes
	) as t 
	where year(fecha_num1)>=@ao

	--1.2 Registran en HIS un estado nutricional en condicin de normalidad Z006 
	select *
	into #his_minsa_num2
	from (
			select a.num_Doc, a.renaes, max(b.fecha_atencion) fecha_num2, num2=1
			from #his_minsa_den a
			inner join #his_minsa b on  a.num_doc=b.num_doc and a.renaes=b.renaes
			where b.cod_item='Z006'
			and b.valor_lab in ('TP','PT','PE')
			and ( b.fecha_atencion between dateadd(dd,60,a.fecha_dx) and dateadd(dd,100,a.fecha_dx) )	
			and b.fecha_atencion<=@fec_eval
			group by a.num_Doc, a.renaes
	) as t 
	where year(fecha_num2)>=@ao

--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
insert into #tabla_reporte
select a.renaes, a.num_doc, a.fecha_dx
, ao, mes
, den=1
, iif(b.num1=1 or c.num2=1,1,0) num
, isnull(b.num1,0) num1
, b.fecha_num1
, isnull(c.num2,0) num2
, c.fecha_num2
from #his_minsa_den a
left join #his_minsa_num1 b on a.renaes=b.renaes and a.num_doc=b.num_doc
left join #his_minsa_num2 c on a.renaes=c.renaes and a.num_doc=c.num_doc

drop table #his_minsa_den
drop table #his_minsa_num1
drop table #his_minsa_num2

set @mes_inicio = @mes_inicio + 1
end

--===================
-- REPORTE
--===================
--drop table BD_HISINDICADORES.dbo.DL1153_2023_CG04_NioRiesgoNutricional

drop table TRAMAHIS_DL_CG04_2023

select *
, row_number() over (partition by num_doc, renaes order by num desc, fecha_dx asc, mes asc) id 
into #tabla_reporte_final 
from #tabla_reporte

select 
B.Disa Diris, CASE 
	WHEN B.Departamento='LIMA' AND B.Provincia='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.Departamento='LIMA' AND B.Provincia<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.Departamento END Departamento
, B.Provincia Provincia
, B.Distrito Distrito
, case when b.Disa like '%diris%' then b.Disa else B.Red end Red
, b.MicroRed MicroRed
, b.Categoria_Establecimiento cat_estab
, b.Nombre_Establecimiento eess_nombre
, a.*
into TRAMAHIS_DL_CG04_2023
from #tabla_reporte_final a
inner join ESTABLECIMIENTOS b on convert(int,a.renaes)=convert(int,b.Codigo_Unico)
--where ( (b.CAT_ESTAB in ('I-1','I-2','I-3','I-4')) or (b.CAT_ESTAB in ('II-1','II-2','II-E') and b.CAMAS<=50) )
and b.Codigo_Sector=7 and a.id=1

		--- NO CONSIDERAR ESTABLECIMIENTOS SIN RED.
		delete from TRAMAHIS_DL_CG04_2023 where CAT_ESTAB in ('I-1','I-2','I-3','I-4') and red like '%no pertenece%'

		--- NO CONSIDERAR ESTABLECIMIENTOS DE SALUD MENTAL.
		delete from TRAMAHIS_DL_CG04_2023 where eess_nombre like '%salud%mental%'

select Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 
, sum(den) den, sum(num) num, sum(num_1) num1, sum(num_2) num_2
from TRAMAHIS_DL_CG04_2023
group by Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 


drop table #his_minsa
drop table #tabla_reporte
drop table #tabla_reporte_final
-- =D

--select ao, mes, Provincia, Distrito, Red, MicroRed, renaes, eess_nombre, num_doc, fecha_dx, den, num  from TRAMAHIS_DL_CG04_2023


