﻿/*==============================================================================
FICHA:  Porcentaje de Personas de 50 a 70 años de edad que se han realizado 
prueba de tamizaje de cáncer de colon-recto
ELABORACION: DIRESA SAN MARTIN - JCAR
==============================================================================*/
use DataHIS
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select 
	convert(date,FECHA_ATENCION) fecha_atencion
	, convert(int,e.Codigo_Unico) renaes
	, p.ID_TIPO_DOCUMENTO id_tipo_doc
	, p.NUMERO_DOCUMENTO num_doc
	, TIPO_DIAGNOSTICO tipo_dx
	, CODIGO_ITEM cod_item  
	, valor_lab
into #his_minsa
from HIS_Nominal h
left join ESTABLECIMIENTOS e on h.ID_ESTABLECIMIENTO=e.Id_Establecimiento
inner join PACIENTE p on h.ID_PACIENTE=p.ID_PACIENTE --with (nolock)
where --sw=1 and													--Validacion de tipo y numero de documento
(convert(int,edad_reg) between 50 and 70) and TIPO_EDAD='A'


--***************************************************
--					SINTAXIS
--***************************************************
declare @mes_eval int,
		@año int 

set @mes_eval=2 --<=========== Mes de evaluación
set @año=2023 --<============= Año de evaluación 

--%%%%%%%%%%%%%%%%
-- DENOOMINADOR
--%%%%%%%%%%%%%%%%
--1. Total de personas de 50 a 70 años identificados con Documento de Identidad atendidos por todas las causas y registrados en el HIS
select distinct renaes, id_tipo_doc, num_doc, den=1
into #dpcan_den
from #his_minsa
where year(fecha_atencion)=@año
and month(fecha_atencion)<=@mes_eval
	
--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%

--1. Personas del denominador a quienes que se les ha entregado el resultado del test de sangre oculta en heces y registradas en el HIS con diagnóstico definitivo, lab A (resultado positivo) o N (resultado negativo) 
select distinct renaes, id_tipo_doc, num_doc, num=1
into #dpcan_num
from #his_minsa
where year(fecha_atencion)=@año
and month(fecha_atencion)<=@mes_eval
and tipo_dx='D'
and cod_item='82270'
and valor_lab in ('N','A')


--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
select @año año, renaes, sum(den) den, sum(num) num
into #tabla_reporte
from (
		select a.*, isnull(b.num,0) num
		from #dpcan_den a
		left join #dpcan_num b on a.renaes=b.renaes and a.id_tipo_doc=b.id_tipo_doc and a.num_doc=b.num_doc
) as t group by renaes 


drop table #dpcan_den
drop table #dpcan_num

--===================
-- REPORTE
--===================
--drop table BD_HISINDICADORES.dbo.DL1153_2023_CG11_PersonasTamizajeCancerColon

drop table TRAMAHIS_DL_CG11_2023

select 
B.Disa Diris, CASE 
	WHEN B.Departamento='LIMA' AND B.Provincia='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.Departamento='LIMA' AND B.Provincia<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.Departamento END Departamento
, B.Provincia Provincia
, B.Distrito Distrito
, case when b.Disa like '%diris%' then b.Disa else B.Red end Red
, b.MicroRed MicroRed
, b.Categoria_Establecimiento cat_estab
, b.Nombre_Establecimiento eess_nombre
, a.*
into TRAMAHIS_DL_CG11_2023
from #tabla_reporte a
inner join ESTABLECIMIENTOS b on convert(int,a.renaes)=convert(int,b.Codigo_Unico)
where b.Categoria_Establecimiento in ('I-3','I-4','II-1') and convert(int,b.Codigo_Sector)=7

		--- NO CONSIDERAR ESTABLECIMIENTOS SIN RED.
		delete from TRAMAHIS_DL_CG11_2023 where CAT_ESTAB in ('I-1','I-2','I-3','I-4') and Red like '%no pertenece%'

		--- NO CONSIDERAR ESTABLECIMIENTOS DE SALUD MENTAL.
		delete from TRAMAHIS_DL_CG11_2023 where eess_nombre like '%salud%mental%'

select * from TRAMAHIS_DL_CG11_2023

drop table #his_minsa
drop table #tabla_reporte
-- =D