/*==============================================================================
FICHA: Indicador N15 - Porcentaje de adolescentes que reciben preventivamente 
suplementacin de hierro ms cido flico
ELABORACION: DIRESA SAN MARTN - JCAR
==============================================================================*/
use DataHIS
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, e.Codigo_Unico renaes
	, convert(date,FECHA_ATENCION) fecha_atencion
	, p.ID_TIPO_DOCUMENTO id_tipo_doc
	, p.NUMERO_DOCUMENTO num_doc
	, fecha_registro
	, h.CODIGO_ITEM cod_item
	, valor_lab
into #his_minsa
from HIS_Nominal h 
left join ESTABLECIMIENTOS e on h.ID_ESTABLECIMIENTO=e.Id_Establecimiento
inner join PACIENTE p on h.ID_PACIENTE=p.ID_PACIENTE --with (nolock)
where ID_TIPO_DOCUMENTO in (1,2,3,4) --and sw=1
and (convert(int,edad_reg) between 12 and 17) and TIPO_EDAD='A' 
and GENERO='F'


--***************************************************
--					SINTAXIS
--***************************************************
create table #tabla_reporte
(
renaes int,
tipo_doc int,
num_doc nvarchar(15),
fecha_atencion date,
ao int,
mes int,
den int,
num int
)


declare @mes_inicio int,
		@mes_eval int,
		@ao int ,
		@fec_eval date

set @mes_inicio=1 --<========= Mes inicio
set @mes_eval=2 --<=========== Mes de evaluacin
set @ao=2023 --<============= Ao de evaluacin 

while @mes_inicio<=@mes_eval
begin

--%%%%%%%%%%%%%%%%
--  DENOMINADOR
--%%%%%%%%%%%%%%%%

--1.Adolescentes mujeres de 12 a 17 aos fueron atendidas por el establecimiento de salud por cualquier motivo de consulta.
select distinct id_cita, renaes, fecha_atencion, id_tipo_doc, num_doc, den=1
into #his_minsa_den
from #his_minsa
where year(fecha_atencion)=@ao	
and month(fecha_atencion)=@mes_inicio

	--1.1 Se excluye adolescentes gestantes
	delete from #his_minsa_den where convert(nvarchar(1),id_tipo_doc)+num_doc in (select distinct convert(nvarchar(1),id_tipo_doc)+num_doc from #his_minsa 
											where cod_item in ('Z3491','Z3492','Z3493','Z3591','Z3592','Z3593','Z359','Z349') and year(fecha_atencion)=@ao	and month(fecha_atencion)<=@mes_inicio)
	--1.2 Se excluye adolescentes con diagnstico de anemia
	delete from #his_minsa_den where convert(nvarchar(1),id_tipo_doc)+num_doc in (select distinct convert(nvarchar(1),id_tipo_doc)+num_doc from #his_minsa 
											where cod_item in ('D500','D508','D509','D649') and year(fecha_atencion)=@ao and month(fecha_atencion)<=@mes_inicio)
	--1.3 Se excluye adolescentes que acuden solo por vacunas Covid
	delete from #his_minsa_den where id_cita in (select distinct id_cita from #his_minsa 
											where cod_item in ('90749.01','90749.02') and year(fecha_atencion)=@ao and month(fecha_atencion)=@mes_inicio)

	--1.4 Se excluye atendidas en Centros Comunitarios de Salud Mental.
	delete from #his_minsa_den where renaes in (select distinct Codigo_Unico from ESTABLECIMIENTOS where Nombre_Establecimiento like '%SALUD%MENTAL%')

--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%

--1.Adolescentes del denominador, que recibieron preventivamente suplemento de hierro ms cido flico
select distinct id_cita, renaes, fecha_atencion, id_tipo_doc, num_doc, num=1
into #his_minsa_num
from #his_minsa
where year(fecha_atencion)=@ao	
and month(fecha_atencion)=@mes_inicio
and cod_item='99199.26' and valor_lab='TA'

--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
insert into #tabla_reporte
select distinct a.renaes, a.id_tipo_doc, a.num_doc, a.fecha_atencion, year(a.fecha_atencion) ao, month(a.fecha_atencion) mes, a.den, isnull(b.num,0) num
from #his_minsa_den a
left join #his_minsa_num b on a.id_cita=b.id_cita and a.renaes=b.renaes and a.fecha_atencion=b.fecha_atencion and a.id_tipo_doc=b.id_tipo_doc and a.num_doc=b.num_doc

drop table #his_minsa_den
drop table #his_minsa_num

set @mes_inicio = @mes_inicio + 1
end

--===================
-- REPORTE
--===================
--drop table BD_HISINDICADORES.dbo.DL1153_2023_CG15_SupleAdoslecente

drop table TRAMAHIS_DL_CG15_2023

select 
B.Disa Diris, CASE 
	WHEN B.Departamento='LIMA' AND B.Provincia='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.Departamento='LIMA' AND B.Provincia<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.Departamento END Departamento
, B.Provincia Provincia
, B.Distrito Distrito
, case when b.Disa like '%diris%' then b.Disa else B.Red end Red
, b.MicroRed MicroRed
, b.Categoria_Establecimiento cat_estab
, b.Nombre_Establecimiento eess_nombre
, a.*
into TRAMAHIS_DL_CG15_2023
from  (
		select * 
		, row_number() over (partition by tipo_doc, num_doc order by num desc, fecha_atencion asc) id 
		from #tabla_reporte
) a
inner join ESTABLECIMIENTOS b on convert(int,a.renaes)=convert(int,b.Codigo_Unico)
where ( (b.Categoria_Establecimiento in ('I-1','I-2','I-3','I-4')) or (b.Categoria_Establecimiento in ('II-1','II-2','II-E'))) --and b.CAMAS<=50
 and b.Codigo_Sector=7 and a.id=1

		--- NO CONSIDERAR ESTABLECIMIENTOS SIN RED.
		delete from TRAMAHIS_DL_CG15_2023 where CAT_ESTAB in ('I-1','I-2','I-3','I-4') and Red like '%no pertenece%'

		--- NO CONSIDERAR ESTABLECIMIENTOS DE SALUD MENTAL.
		delete from TRAMAHIS_DL_CG15_2023 where eess_nombre like '%salud%mental%'

select Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 
, sum(den) den, sum(num) num 
from TRAMAHIS_DL_CG15_2023
group by Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 


drop table #his_minsa
drop table #tabla_reporte
-- =D

--select * from TRAMAHIS_DL_CG15_2023 